"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.tsx
var src_exports = {};
__export(src_exports, {
  FloatingMenuPlugin: () => FloatingMenuPlugin
});
module.exports = __toCommonJS(src_exports);

// src/FloatingMenuPlugin.tsx
var import_react2 = require("react");
var import_react_dom = require("react-dom");
var import_lexical = require("lexical");
var import_LexicalComposerContext = require("@lexical/react/LexicalComposerContext");
var import_dom = require("@floating-ui/dom");

// src/hooks/usePointerInteractions.tsx
var import_react = require("react");
function usePointerInteractions() {
  const [isPointerDown, setIsPointerDown] = (0, import_react.useState)(false);
  const [isPointerReleased, setIsPointerReleased] = (0, import_react.useState)(true);
  (0, import_react.useEffect)(() => {
    const handlePointerUp = () => {
      setIsPointerDown(false);
      setIsPointerReleased(true);
      document.removeEventListener("pointerup", handlePointerUp);
    };
    const handlePointerDown = () => {
      setIsPointerDown(true);
      setIsPointerReleased(false);
      document.addEventListener("pointerup", handlePointerUp);
    };
    document.addEventListener("pointerdown", handlePointerDown);
    return () => {
      document.removeEventListener("pointerdown", handlePointerDown);
    };
  }, []);
  return { isPointerDown, isPointerReleased };
}

// src/FloatingMenuPlugin.tsx
var import_jsx_runtime = require("react/jsx-runtime");
var DEFAULT_DOM_ELEMENT = document.body;
function FloatingMenuPlugin({
  element,
  MenuComponent
}) {
  const ref = (0, import_react2.useRef)(null);
  const [coords, setCoords] = (0, import_react2.useState)(void 0);
  const show = coords !== void 0;
  const [editor] = (0, import_LexicalComposerContext.useLexicalComposerContext)();
  const { isPointerDown, isPointerReleased } = usePointerInteractions();
  const calculatePosition = (0, import_react2.useCallback)(() => {
    const domSelection = getSelection();
    const domRange = domSelection?.rangeCount !== 0 && domSelection?.getRangeAt(0);
    if (!domRange || !ref.current || isPointerDown)
      return setCoords(void 0);
    (0, import_dom.computePosition)(domRange, ref.current, { placement: "top" }).then((pos) => {
      setCoords({ x: pos.x, y: pos.y - 10 });
    }).catch(() => {
      setCoords(void 0);
    });
  }, [isPointerDown]);
  const $handleSelectionChange = (0, import_react2.useCallback)(() => {
    if (editor.isComposing())
      return false;
    if (editor.getRootElement() !== document.activeElement) {
      setCoords(void 0);
      return true;
    }
    const selection = (0, import_lexical.$getSelection)();
    if ((0, import_lexical.$isRangeSelection)(selection) && !selection.anchor.is(selection.focus)) {
      calculatePosition();
    } else {
      setCoords(void 0);
    }
    return true;
  }, [editor, calculatePosition]);
  (0, import_react2.useEffect)(() => {
    const unregisterCommand = editor.registerCommand(
      import_lexical.SELECTION_CHANGE_COMMAND,
      $handleSelectionChange,
      import_lexical.COMMAND_PRIORITY_NORMAL
    );
    return unregisterCommand;
  }, [editor, $handleSelectionChange]);
  (0, import_react2.useEffect)(() => {
    if (!show && isPointerReleased) {
      editor.getEditorState().read(() => {
        $handleSelectionChange();
      });
    }
  }, [isPointerReleased, $handleSelectionChange, editor]);
  if (!MenuComponent)
    return null;
  return (0, import_react_dom.createPortal)(
    /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
      "div",
      {
        ref,
        "aria-hidden": !show,
        style: {
          position: "absolute",
          top: coords?.y,
          left: coords?.x,
          visibility: show ? "visible" : "hidden",
          opacity: show ? 1 : 0
        },
        children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(MenuComponent, { editor, shouldShow: show })
      }
    ),
    element ?? DEFAULT_DOM_ELEMENT
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  FloatingMenuPlugin
});
